
// Copyright (c) 2003 Sonic Foundry, Inc. and Sonic Foundry 
// Media Systems, Inc. Neither this code nor any portion 
// thereof maybe reproduced, altered,or otherwise changed, 
// distributed or copied,without the express written 
// permission of Sonic Foundry. 
// All rights reserved.

// BEGINFILE AskButtonArea.js -------------------------------------------------------------------------->

AskButtonArea.prototype = new AreaBase();
function AskButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	this.PrimarySpeakerEmail = "";
	
	this.InitializeArea(container, containingWindow, ID);
	
	function AskButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "AskButtonArea: " + msg);
	}
	
	function AskButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.AddEventHandlers();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
		
		this.HandleButtonState();
	}
	
	function AskButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.RemoveEventHandlers();
	}
	
	function AskButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		this.ScriptEventHandler = new SfEventHandler("AskButtonArea");
		this.ScriptEventHandler.MethodName = "OnScriptEvent";
		this.ScriptEventHandler.Container = this.Container;
		
		MainHelper.EventScript.AddHandler(this.ScriptEventHandler);

		this.DataAvailableEventHandler = new SfEventHandler("AskButtonArea");
		this.DataAvailableEventHandler.MethodName = "OnDataAvailableEvent";
		this.DataAvailableEventHandler.Container = this.Container;
		
		MainHelper.EventDataAvailable.AddHandler(this.DataAvailableEventHandler);
	}

	function AskButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		MainHelper.EventScript.RemoveHandler(this.ScriptEventHandler);
		MainHelper.EventDataAvailable.RemoveHandler(this.DataAvailableEventHandler);
	}
	
	function AskButtonArea.prototype.OnScriptEvent(args)
	{
		this.Debug("OnScriptEvent called");
		switch(args.Command)
		{
			case SfScriptCommandType.EndPresentation:
				this.button.Enable(false);
				break;
		}
	}
	
	function AskButtonArea.prototype.OnDataAvailableEvent(args)
	{
		this.Debug("DataAvailableEvent called");
		this.HandleButtonState();
	}

	function AskButtonArea.prototype.HandleButtonState()
	{
		if (MainHelper.Presentation.IsStandAlone == true)
		{
			// in standalone these are always disabled
			this.button.Enable(false);
			return;
		}

		// live or replay
		if ( (MainHelper.Presentation.ForumEnabled == true) && ((MainHelper.Presentation.Status == PresentationStatus.CaptureInProgress) || (this.PrimarySpeakerEmail != "")))
		{
			this.button.Enable(true);
		}
		else
		{
			this.button.Enable(false);
		}
			
	}
	
	function AskButtonArea.prototype.OnClick()
	{
		if (MainHelper.Presentation.Status == PresentationStatus.CaptureInProgress)
		{
			// needs to be resizeable
			window.popupAsk = WindowHelper.CreateNamedPopup(PopupNames.Forum, "polls", 450, 305, true, false);
			if (window.popupAsk) 
			{
				window.popupAsk.focus();
			}
		}
		else if ( this.PrimarySpeakerEmail != "" )
		{
			window.location = "mailto:" + this.PrimarySpeakerEmail;
		}
	}
}


// ENDFILE AskButtonArea.js ---------------------------------------------------------------------------->

// BEGINFILE ButtonGroupArea.js ------------------------------------------------------------------------>

function ButtonGroupArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.Initialize(container, containingWindow, ID);
	
	function ButtonGroupArea.prototype.Initialize(container, containingWindow, ID)
	{
		this.Debug("Initialize called");
		this.Container = container;
		this.ContaingWindow = containingWindow;
		this.ID = ID;
		SfOnLoad.AddHandler("" + this.Container + ".OnLoad()");
	}
	
	function ButtonGroupArea.prototype.OnLoad()
	{
		this.Debug("OnLoad called");
		var len = this.Buttons.length;
		
		var i;
		for (i=0; i<len; ++i)
		{
			this.Buttons[i].button.ClickHandler = new Function("", 
				this.Container + ".OnClick('" + this.Buttons[i].Container + "');");
		}
	}
	
	function ButtonGroupArea.prototype.OnClick(buttonContainer)
	{
		this.Debug("OnClick called");
		this.Debug("container: " + buttonContainer);

		var len = this.Buttons.length;
		var i;
		for (i=0; i<len; ++i)
		{
			if (this.Buttons[i].Container == buttonContainer)
			{
				this.Buttons[i].OnClick();
			}
			else
			{
				this.Buttons[i].button.SetCheck(false);
			}
		}
	}
	
	function ButtonGroupArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "ButtonGroupArea: " + msg);
	}
}

// ENDFILE ButtonGroupArea.js -------------------------------------------------------------------------->

// BEGINFILE CloseButtonArea.js ------------------------------------------------------------------------>

CloseButtonArea.prototype = new AreaBase();
function CloseButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function CloseButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "CloseButtonArea: " + msg);
	}
	
	function CloseButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function CloseButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
	}
	
	function CloseButtonArea.prototype.OnClick()
	{
		top.close();
	}
}

// ENDFILE CloseButtonArea.js -------------------------------------------------------------------------->

// BEGINFILE FullScreenButtonArea.js ------------------------------------------------------------------->

FullScreenButtonArea.prototype = new AreaBase();
function FullScreenButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function FullScreenButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "FullScreenButtonArea: " + msg);
	}
	
	function FullScreenButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.AddEventHandlers();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function FullScreenButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.RemoveEventHandlers();
	}
	
	function FullScreenButtonArea.prototype.EnableDisableButton()
	{
		this.Debug("EnableDisableButton called");
		if (MainHelper.Presentation.IsAudioOnly == true)
		{
			this.Debug("IsAudioOnly");
			this.button.Enable(false);
		}
		else
		{
			this.Debug("Not IsAudioOnly");
			this.button.Enable(true);
		}
	}
	
	function FullScreenButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.PlayerSetupCompleteEventHandler = new SfEventHandler("FullScreenButtonArea");
		this.PlayerSetupCompleteEventHandler.MethodName = "OnPlayerSetupCompleteEvent";
		this.PlayerSetupCompleteEventHandler.Container = this.Container;
		MainHelper.EventPlayerSetupComplete.AddHandler(this.PlayerSetupCompleteEventHandler);
	}
	
	function FullScreenButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventPlayerSetupComplete.RemoveHandler(this.PlayerSetupCompleteEventHandler);
	}

	function FullScreenButtonArea.prototype.OnPlayerSetupCompleteEvent(args)
	{
		this.Debug("OnPlayerSetupCompleteEvent called");
		this.EnableDisableButton();
	}
	
	function FullScreenButtonArea.prototype.OnClick()
	{
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.FullScreen));
	}
	
}

// ENDFILE FullScreenButtonArea.js --------------------------------------------------------------------->

// BEGINFILE HelpButtonArea.js ------------------------------------------------------------------------->

HelpButtonArea.prototype = new AreaBase();
function HelpButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function HelpButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "HelpButtonArea: " + msg);
	}
	
	function HelpButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function HelpButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
	}
	
	function HelpButtonArea.prototype.OnClick()
	{
		WindowHelper.PopupHelp(GetPopupURL(PopupNames.Help),450,330);
	}
}

// ENDFILE HelpButtonArea.js --------------------------------------------------------------------------->

// BEGINFILE InfoButtonArea.js ------------------------------------------------------------------------->

InfoButtonArea.prototype = new AreaBase();
function InfoButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function InfoButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "InfoButtonArea: " + msg);
	}
	
	function InfoButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		
		this.button.Initialize();
		
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function InfoButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
	}
	
	function InfoButtonArea.prototype.OnClick()
	{
		this.Debug("OnClick");
		
		if (this.button.IsChecked == true)
		{
			return;
		}
		
		this.button.SetCheck(true);
	
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.ShowInfo));
	}
	
}

// ENDFILE InfoButtonArea.js --------------------------------------------------------------------------->

// BEGINFILE MaxSlideButtonArea.js --------------------------------------------------------------------->

MaxSlideButtonArea.prototype = new AreaBase();
function MaxSlideButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function MaxSlideButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "MaxSlideButtonArea: " + msg);
	}
	
	function MaxSlideButtonArea.prototype.RegisterEvents()
	{
		this.Debug("RegisterEvents called");
		this.ScriptEventHandler = new SfEventHandler(this.Container);
		this.ScriptEventHandler.Container = this.Container;
		this.ScriptEventHandler.MethodName = "OnScriptEvent";
		MainHelper.EventScript.AddHandler(this.ScriptEventHandler);
	}
	
	function MaxSlideButtonArea.prototype.UnRegisterEvents()
	{
		this.Debug("UnRegisterEvents called");
		MainHelper.EventScript.RemoveHandler(this.ScriptEventHandler);
	}

	function MaxSlideButtonArea.prototype.OnScriptEvent(args)
	{
		this.Debug("OnScriptEvent: " + args);
		switch(args.Command)
		{
			case SfScriptCommandType.EndPresentation:
				this.button.Enable(false);
				break;
			case SfScriptCommandType.ShowSlide:
				if (args.Index > 0)
				{
					this.button.Enable(true);
				}
				else
				{
					this.button.Enable(false);
				}
				break;
		}
	}

	function MaxSlideButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		if (this.ShouldEnableButtonInBeginning() == true)
		{
			this.button.IsEnabled = true;
		}
		else
		{
			this.button.IsEnabled = false;
		}
		this.button.Initialize();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
		this.RegisterEvents();
	}
	
	function MaxSlideButtonArea.prototype.ShouldEnableButtonInBeginning()
	{
		this.Debug("ShouldEnableButtonInBeginning");
		if (MainHelper.Presentation.Status != PresentationStatus.CaptureInProgress)
		{
			// disable all non-live presentations
			return false;
		}
		
		// it is a live presentation
		if (MainHelper.MaxSlideTimings > 0)
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	function MaxSlideButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.UnRegisterEvents();
	}

	// need to duplicate the functionality in CurrentSlideArea
	// because of Google popup blocker issue	
	function MaxSlideButtonArea.prototype.OnClick()
	{
		this.Debug("OnClick");
		
		if (WindowHelper.IsOpen(MainHelper.PopupWindows.FullSize) == true)
		{
			this.Debug("Is already open");
			return;
		}
		
		MainHelper.PopupWindows.FullSize =
			
			WindowHelper.CreateNamedPopup(
				PopupNames.FullSize,
				"FullSize",
				MainHelper.DefaultFullSizeWindowWidth,
				MainHelper.DefaultFullSizeWindowHeight,
				true,
				true);
	}
}

// ENDFILE MaxSlideButtonArea.js ----------------------------------------------------------------------->

// BEGINFILE MuteButtonArea.js ------------------------------------------------------------------------->

MuteButtonArea.prototype = new AreaBase();
function MuteButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function MuteButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "MuteButtonArea: " + msg);
	}
	
	function MuteButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.AddEventHandlers();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function MuteButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.RemoveEventHandlers();
	}
	
	function MuteButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.PlayerSetupCompleteEventHandler = new SfEventHandler("MuteButtonArea");
		this.PlayerSetupCompleteEventHandler.MethodName = "OnPlayerSetupCompleteEvent";
		this.PlayerSetupCompleteEventHandler.Container = this.Container;
		MainHelper.EventPlayerSetupComplete.AddHandler(this.PlayerSetupCompleteEventHandler);
		
 		this.VolumeChangedEventHandler = new SfEventHandler("MuteButtonArea");
		this.VolumeChangedEventHandler.MethodName = "OnVolumeChangedEvent";
		this.VolumeChangedEventHandler.Container = this.Container;
		MainHelper.EventVolumeChanged.AddHandler(this.VolumeChangedEventHandler);
	}
	
	function MuteButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventPlayerSetupComplete.RemoveHandler(this.PlayerSetupCompleteEventHandler);
		MainHelper.EventVolumeChanged.RemoveHandler(this.VolumeChangedEventHandler);
	}

	function MuteButtonArea.prototype.OnPlayerSetupCompleteEvent(args)
	{
		this.Debug("OnPlayerSetupCompleteEvent called");
		this.button.Enable(true);
	}
	
	function MuteButtonArea.prototype.OnVolumeChangedEvent(args)
	{
		this.Debug("OnVolumeChangedEvent: " + args);
		switch(args.ChangeType)
		{
			case SfVolumeChangeType.Muted:
				this.button.SetCheck(true);
				this.button.SetToolTip("Mute Off");
				break;
			case SfVolumeChangeType.UnMuted:
				this.button.SetCheck(false);
				this.button.SetToolTip("Mute");
				break;
		}
	}

	function MuteButtonArea.prototype.OnClick()
	{
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.Mute));
	}
	
}

// ENDFILE MuteButtonArea.js --------------------------------------------------------------------------->

// BEGINFILE NextSlideButtonArea.js -------------------------------------------------------------------->

NextSlideButtonArea.prototype = new AreaBase();
function NextSlideButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function NextSlideButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "NextSlideButtonArea: " + msg);
	}
	
	function NextSlideButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		
		this.button.Initialize();
		
		this.AddEventHandlers();
		
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
		this.HandleButtonState(-1);
	}
	
	function NextSlideButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		
		this.RemoveEventHandlers();
	}
	
	function NextSlideButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.SlideChangedEventHandler = new SfEventHandler("NextSlideButtonArea");
		this.SlideChangedEventHandler.MethodName = "OnSlideChangedEvent";
		this.SlideChangedEventHandler.Container = this.Container;
		MainHelper.EventSlideChanged.AddHandler(this.SlideChangedEventHandler);
		
		this.CommandEventHandler = new SfEventHandler("NextSlideButtonArea");
		this.CommandEventHandler.MethodName = "OnCommandEvent";
		this.CommandEventHandler.Container = this.Container;
		MainHelper.EventCommand.AddHandler(this.CommandEventHandler);

		this.PlayBeginEventHandler = new SfEventHandler("NextSlideButtonArea");
		this.PlayBeginEventHandler.MethodName = "OnPlayBeginEvent";
		this.PlayBeginEventHandler.Container = this.Container;
		MainHelper.EventPlayBegin.AddHandler(this.PlayBeginEventHandler);
	}
	
	function NextSlideButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventSlideChanged.RemoveHandler(this.SlideChangedEventHandler);
		MainHelper.EventCommand.RemoveHandler(this.CommandEventHandler);
		MainHelper.EventPlayBegin.RemoveHandler(this.PlayBeginEventHandler);
	}

	function NextSlideButtonArea.prototype.OnSlideChangedEvent(args)
	{
		this.Debug("OnSlideChanged called, :" + args.Index);
		var index = args.Index;
		this.HandleButtonState(Number(index));
	}
	
	function NextSlideButtonArea.prototype.OnCommandEvent(args)
	{
		this.Debug("OnCommandEvent: " + args);
		switch(args.Command)
		{
			case SfCommandType.ShowSlideShow:
				this.Show();
				break;
			case SfCommandType.ShowSlideList:
				this.Hide();
				break;
		}
	}

	function NextSlideButtonArea.prototype.OnPlayBeginEvent(args)
	{
		this.Debug("OnPlayBeginEvent");
		this.HandleButtonState(-1);
	}

	function NextSlideButtonArea.prototype.OnClick()
	{
		this.Debug("NextSlideHandler called");
		var currentSlide = MainHelper.CurrentSlideNumber;
		var maxSlide = MainHelper.MaxSlideTimings;
		this.Debug("CurrentSlide: " + currentSlide + ", maxSlide: " + maxSlide);
		if (currentSlide == -1 && maxSlide > 0)
		{
			var args = new CommandArgs(SfCommandType.NavigateToSlide);
			args.SlideNumber = 1;
			MainHelper.EventCommand.Post(args);
		}
		else if (currentSlide < maxSlide)
		{
			var args = new CommandArgs(SfCommandType.NavigateToSlide);
			args.SlideNumber = currentSlide + 1;
			MainHelper.EventCommand.Post(args);
		}
		else
		{
			SfDebug.DPF(SfDebug.ErrMsgSubCritical, "Next slide should not be called here");
			return;
		}

		this.TimedDisable(1000);
	}
	
	this.InTimeDisabled = false;
	this.EnableLater = false;
	function NextSlideButtonArea.prototype.TimedDisable(milliSeconds)
	{
		this.Debug("TimedDisable called: " + milliSeconds);
		
		this.InTimeDisabled = true;
		this.button.Enable(false);

		setTimeout(this.Container + '.TimedEnable()', milliSeconds);
	}
	
	function NextSlideButtonArea.prototype.TimedEnable()
	{
		this.Debug("TimedEnable called");
		
		if (this.EnableLater == true)
		{
			this.Debug("Enabling Next button");
			this.button.Enable(true);
		}
		else
		{
			this.Debug("Disabling Next button");
			this.button.Enable(false);
		}
		
		this.InTimeDisabled = false;
	}

	function NextSlideButtonArea.prototype.HandleButtonState(currentSlide)
	{
		this.Debug("HandleButtonState called, CurrentSlide: " + currentSlide);
		this.EnableLater = false;
		
		if (MainHelper.Presentation.Status == PresentationStatus.CaptureInProgress)
		{
			// disable in live mode
			this.button.Enable(false);
			return;
		}
		
		var maxSlide = MainHelper.MaxSlideTimings;
		this.Debug("MaxSlide: " + maxSlide);
		if (currentSlide == -1)
		{
			// uninitialized
			if (maxSlide > 0)
			{
				this.button.Enable(true);
			}
			else
			{
				this.button.Enable(false);
			}
			return;
		}
		
		if (currentSlide < maxSlide)
		{
			if (this.InTimeDisabled == true)
			{
				this.EnableLater = true;
			}
			else
			{
				this.button.Enable(true);
			}
		}
		else
		{
			this.button.Enable(false);
		}
	}
	
}

// ENDFILE NextSlideButtonArea.js ---------------------------------------------------------------------->

// BEGINFILE OptionsButtonArea.js ---------------------------------------------------------------------->

OptionsButtonArea.prototype = new AreaBase();
function OptionsButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function OptionsButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "OptionsButtonArea: " + msg);
	}
	
	function OptionsButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
		
		this.HandleButtonState();
	}
	
	function OptionsButtonArea.prototype.HandleButtonState()
	{
		if (MainHelper.Presentation.IsStandAlone == true)
		{
			// in standalone these are always disabled
			this.button.Enable(false);
		}
		else
		{
			// live or replay
			this.button.Enable(true);
		}		
	}
	
	function OptionsButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
	}
	
	function OptionsButtonArea.prototype.OnClick()
	{
		// needs to be resizeable
		window.popupoptions = WindowHelper.CreateNamedPopup(PopupNames.Options,"__options",400,200,false,false);
		if (window.popupoptions) 
		{
			window.popupoptions.focus();
		}
	}
}

// ENDFILE OptionsButtonArea.js ------------------------------------------------------------------------>

// BEGINFILE PauseButtonArea.js ------------------------------------------------------------------------>

PauseButtonArea.prototype = new AreaBase();
function PauseButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function PauseButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "PauseButtonArea: " + msg);
	}
	
	function PauseButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.AddEventHandlers();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function PauseButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.RemoveEventHandlers();
	}
	
	function PauseButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.PlayerSetupCompleteEventHandler = new SfEventHandler("PauseButtonArea");
		this.PlayerSetupCompleteEventHandler.MethodName = "OnPlayerSetupCompleteEvent";
		this.PlayerSetupCompleteEventHandler.Container = this.Container;
		MainHelper.EventPlayerSetupComplete.AddHandler(this.PlayerSetupCompleteEventHandler);
		
		this.PlayerStateChangedEventHandler = new SfEventHandler("PauseButtonArea");
		this.PlayerStateChangedEventHandler.MethodName = "OnPlayerStateChangedEvent";
		this.PlayerStateChangedEventHandler.Container = this.Container;
		MainHelper.EventPlayerStateChanged.AddHandler(this.PlayerStateChangedEventHandler);
	}
	
	function PauseButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventPlayerSetupComplete.RemoveHandler(this.PlayerSetupCompleteEventHandler);
		MainHelper.EventPlayerStateChanged.RemoveHandler(this.PlayerStateChangedEventHandler);
	}

	function PauseButtonArea.prototype.OnPlayerSetupCompleteEvent(args)
	{
		this.Debug("OnPlayerSetupCompleteEvent called");
		if (MainHelper.Presentation.Status == PresentationStatus.CaptureInProgress)
		{
			this.button.Enable(false);
		}
		else
		{
			this.button.Enable(true);
		}
	}
	
	function PauseButtonArea.prototype.OnPlayerStateChangedEvent(state)
	{
		this.Debug("OnPlayerStateChangedEvent: " + state);
		if (MainHelper.Presentation.Status == PresentationStatus.CaptureInProgress)
		{
			if (this.button.IsEnabled == true)
			{
				this.button.Enable(false);
			}
			return;
		}

		var pauseIsEnabled = true;
		switch(state)
		{
			case PlayState.Stopped:
			case PlayState.Ready:
			case PlayState.Paused:
				pauseIsEnabled = false;
				break;
			case PlayState.Playing:
				pauseIsEnabled = true;
				break;
			default:
				return;
		}
		
		this.Debug("ButtonEnabledState: " + pauseIsEnabled);
		if (pauseIsEnabled)
		{
			if (this.button.IsEnabled == false)
			{
				this.button.Enable(true);
			}
		}
		else
		{
			if (this.button.IsEnabled == true)
			{
				this.button.Enable(false);
			}
		}
	}

	function PauseButtonArea.prototype.OnClick()
	{
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.Pause));
	}
	
}

// ENDFILE PauseButtonArea.js -------------------------------------------------------------------------->

// BEGINFILE PlayButtonArea.js ------------------------------------------------------------------------->

PlayButtonArea.prototype = new AreaBase();
function PlayButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function PlayButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "PlayButtonArea: " + msg);
	}
	
	function PlayButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.AddEventHandlers();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function PlayButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.RemoveEventHandlers();
	}
	
	function PlayButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.PlayerSetupCompleteEventHandler = new SfEventHandler("PlayButtonArea");
		this.PlayerSetupCompleteEventHandler.MethodName = "OnPlayerSetupCompleteEvent";
		this.PlayerSetupCompleteEventHandler.Container = this.Container;
		MainHelper.EventPlayerSetupComplete.AddHandler(this.PlayerSetupCompleteEventHandler);
		
		this.PlayerStateChangedEventHandler = new SfEventHandler("PlayButtonArea");
		this.PlayerStateChangedEventHandler.MethodName = "OnPlayerStateChangedEvent";
		this.PlayerStateChangedEventHandler.Container = this.Container;
		MainHelper.EventPlayerStateChanged.AddHandler(this.PlayerStateChangedEventHandler);
	}
	
	function PlayButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventPlayerSetupComplete.RemoveHandler(this.PlayerSetupCompleteEventHandler);
		MainHelper.EventPlayerStateChanged.RemoveHandler(this.PlayerStateChangedEventHandler);
	}

	function PlayButtonArea.prototype.OnPlayerSetupCompleteEvent(args)
	{
		this.Debug("OnPlayerSetupCompleteEvent called");
		this.button.Enable(true);
	}
	
	function PlayButtonArea.prototype.OnPlayerStateChangedEvent(state)
	{
		this.Debug("OnPlayerStateChangedEvent: " + state);
		var playIsEnabled = true;
		
		switch(state)
		{
			case PlayState.Stopped:
			case PlayState.Ready:
			case PlayState.Paused:
				playIsEnabled = true;
				break;
			case PlayState.Playing:
				playIsEnabled=false;
				break;
			default:
				return;
		}
		
		this.Debug("ButtonEnabledState: " + playIsEnabled);
		if (playIsEnabled)
		{
			if (this.button.IsEnabled == false)
			{
				this.button.Enable(true);
			}
		}
		else
		{
			if (this.button.IsEnabled == true)
			{
				this.button.Enable(false);
			}
		}
	}

	function PlayButtonArea.prototype.OnClick()
	{
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.Play));
	}
	
}

// ENDFILE PlayButtonArea.js --------------------------------------------------------------------------->

// BEGINFILE PollButtonArea.js ------------------------------------------------------------------------->

PollButtonArea.prototype = new AreaBase();
function PollButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function PollButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "PollButtonArea: " + msg);
	}
	
	function PollButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
		
		this.HandleButtonState();
	}
	
	function PollButtonArea.prototype.HandleButtonState()
	{
		this.Debug("HandleButtonState called");

		// in standalone these are always disabled
		if (MainHelper.Presentation.IsStandAlone == true)
		{
			this.Debug("disabling for standalone");
			this.button.Enable(false);
			return;
		}
		
		if ( (MainHelper.Presentation.PollsEnabled == false) && (MainHelper.Presentation.PollResultsEnabled == false) )
		{
			this.Debug("no polls are present");
			this.button.Enable(false);
		}
		else
		{
			this.Debug("polls present");
			this.button.Enable(true);
		}
	}
	
	function PollButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
	}
	
	function PollButtonArea.prototype.OnClick()
	{
		this.Debug("OnClick called");
		// needs to be resizeable
		window.popupPoll = WindowHelper.CreateNamedPopup(PopupNames.ShowPolls, "polls", 600, 450, true, false);
		if (window.popupPoll) 
		{
			window.popupPoll.focus();
		}
	}
}

// ENDFILE PollButtonArea.js --------------------------------------------------------------------------->

// BEGINFILE PresentationDetailsButtonArea.js ---------------------------------------------------------->

PresentationDetailsButtonArea.prototype = new AreaBase();
function PresentationDetailsButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function PresentationDetailsButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "PresentationDetailsButtonArea: " + msg);
	}
	
	function PresentationDetailsButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
		this.button.Enable(true);
	}
	
	function PresentationDetailsButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
	}
	
	function PresentationDetailsButtonArea.prototype.OnClick()
	{
		window.popupDetails = WindowHelper.CreateNamedPopup(PopupNames.PresentationDetails, "pd", 650, 300, true, false);
		window.popupDetails.focus();
	}
}

// ENDFILE PresentationDetailsButtonArea.js ------------------------------------------------------------>

// BEGINFILE PreviousSlideButtonArea.js ---------------------------------------------------------------->

PreviousSlideButtonArea.prototype = new AreaBase();
function PreviousSlideButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function PreviousSlideButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "PreviousSlideButtonArea: " + msg);
	}
	
	function PreviousSlideButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		
		this.button.Initialize();
		
		this.AddEventHandlers();
		
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
		this.HandleButtonState(-1);
	}
	
	function PreviousSlideButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		
		this.RemoveEventHandlers();
	}
	
	function PreviousSlideButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.SlideChangedEventHandler = new SfEventHandler("PreviousSlideButtonArea");
		this.SlideChangedEventHandler.MethodName = "OnSlideChangedEvent";
		this.SlideChangedEventHandler.Container = this.Container;
		MainHelper.EventSlideChanged.AddHandler(this.SlideChangedEventHandler);

		this.CommandEventHandler = new SfEventHandler("PreviousSlideButtonArea");
		this.CommandEventHandler.MethodName = "OnCommandEvent";
		this.CommandEventHandler.Container = this.Container;
		MainHelper.EventCommand.AddHandler(this.CommandEventHandler);
		
		this.PlayBeginEventHandler = new SfEventHandler("PreviousSlideButtonArea");
		this.PlayBeginEventHandler.MethodName = "OnPlayBeginEvent";
		this.PlayBeginEventHandler.Container = this.Container;
		MainHelper.EventPlayBegin.AddHandler(this.PlayBeginEventHandler);
		
	}
	
	function PreviousSlideButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventSlideChanged.RemoveHandler(this.SlideChangedEventHandler);
		MainHelper.EventCommand.RemoveHandler(this.CommandEventHandler);
		MainHelper.EventPlayBegin.RemoveHandler(this.PlayBeginEventHandler);
	}

	function PreviousSlideButtonArea.prototype.OnSlideChangedEvent(args)
	{
		this.Debug("OnSlideChanged called, :" + args.Index);
		var index = args.Index;
		this.HandleButtonState(Number(index));
	}
	
	function PreviousSlideButtonArea.prototype.OnCommandEvent(args)
	{
		this.Debug("OnCommandEvent: " + args);
		switch(args.Command)
		{
			case SfCommandType.ShowSlideShow:
				this.Show();
				break;
			case SfCommandType.ShowSlideList:
				this.Hide();
				break;
		}
	}

	function PreviousSlideButtonArea.prototype.OnPlayBeginEvent(args)
	{
		this.Debug("OnPlayBeginEvent");
		this.HandleButtonState(-1);
	}

	function PreviousSlideButtonArea.prototype.OnClick()
	{
		this.Debug("Previous SlideHandler called");
		
		var currentSlide = MainHelper.CurrentSlideNumber;
		this.Debug("OnClick CurrentSlide: " + currentSlide);
		
		var toJumpTo;
		if (MainHelper.PresentationEnded == true)
		{
			toJumpTo = currentSlide;
		}
		else if (currentSlide > 1)
		{
			toJumpTo = currentSlide-1;
		}
		else
		{
			SfDebug.DPF(SfDebug.ErrMsgSubCritical, "PreviousSlide should not be called here");
			return;
		}

		var args = new CommandArgs(SfCommandType.NavigateToSlide);
		args.SlideNumber = (toJumpTo);
		MainHelper.EventCommand.Post(args);
		
		this.TimedDisable(1000);
	}
	
	this.InTimeDisabled = false;
	this.EnableLater = false;
	function PreviousSlideButtonArea.prototype.TimedDisable(milliSeconds)
	{
		this.Debug("TimedDisable called for: " + milliSeconds);
		
		this.InTimeDisabled = true;
		this.button.Enable(false);

		setTimeout(this.Container + '.TimedEnable()', milliSeconds);
	}
	
	function PreviousSlideButtonArea.prototype.TimedEnable()
	{
		this.Debug("TimedEnable called");
		if (this.EnableLater == true)
		{
			this.Debug("Enabling Previous button");
			this.button.Enable(true);
		}
		else
		{
			this.Debug("Disabling Previous button");
			this.button.Enable(false);
		}
		
		this.InTimeDisabled = false;
	}

	function PreviousSlideButtonArea.prototype.HandleButtonState(currentSlide)
	{
		this.Debug("HandleButtonState called, CurrentSlide: " + currentSlide);
		this.EnableLater = false;
		
		if (MainHelper.Presentation.Status == PresentationStatus.CaptureInProgress)
		{
			// disable in live mode
			this.button.Enable(false);
			return;
		}
		
		if (currentSlide < 2)
		{
			// uninitialized, or slide number 1
			this.button.Enable(false);
			return;
		}
		
		if (this.InTimeDisabled == true)
		{
			this.EnableLater = true;
		}
		else
		{
			this.button.Enable(true);
		}
	}
	
}

// ENDFILE PreviousSlideButtonArea.js ------------------------------------------------------------------>

// BEGINFILE SlideListButtonArea.js -------------------------------------------------------------------->

SlideListButtonArea.prototype = new AreaBase();
function SlideListButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function SlideListButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "SlideListButtonArea: " + msg);
	}
	
	function SlideListButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		
		this.InitializeButtonState();
				
		this.AddEventHandlers();
		
	}
	
	function SlideListButtonArea.prototype.InitializeButtonState()
	{
		this.Debug("InitializeButtonState called");
		
		if (MainHelper.MaxSlideTimings < 1)
		{
			this.Debug("No slides so disabling");
			this.button.IsEnabled = false;
		}
		this.button.Initialize();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function SlideListButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		
		this.RemoveEventHandlers();
	}
	
	function SlideListButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.CommandEventHandler = new SfEventHandler("SlideListButtonArea");
		this.CommandEventHandler.MethodName = "OnCommandEvent";
		this.CommandEventHandler.Container = this.Container;
		MainHelper.EventCommand.AddHandler(this.CommandEventHandler);
		
		this.SlideChangedEventHandler = new SfEventHandler(this.Container);
		this.SlideChangedEventHandler.Container = this.Container;
		this.SlideChangedEventHandler.MethodName = "OnSlideChangedEvent";
		MainHelper.EventSlideChanged.AddHandler(this.SlideChangedEventHandler);	
	}
	
	function SlideListButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventCommand.RemoveHandler(this.CommandEventHandler);
		MainHelper.EventSlideChanged.RemoveHandler(this.SlideChangedEventHandler);
	}

	function SlideListButtonArea.prototype.OnCommandEvent(args)
	{
		this.Debug("OnCommandEvent: " + args);
		switch(args.Command)
		{
			case SfCommandType.ShowSlideShow:
				this.button.SetCheck(false);
				break;
		}
	}
	
	function SlideListButtonArea.prototype.OnSlideChangedEvent(args)
	{
		this.Debug("OnSlideChangedEvent: " + args);
		if (this.button.IsEnabled == false)
		{
			this.button.Enable(true);
		}
	}

	function SlideListButtonArea.prototype.OnClick()
	{
		this.Debug("OnClick");
		
		if (this.button.IsChecked == true)
		{
			return;
		}
		
		this.button.SetCheck(true);
	
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.ShowSlideList));
	
		
		var slide = SfDOM.FindElementFromID(document, "lblSlide");
		if (slide)
		{
			slide.style.visibility = 'hidden';
		}
	}
	
}

// ENDFILE SlideListButtonArea.js ---------------------------------------------------------------------->

// BEGINFILE SlideShowButtonArea.js -------------------------------------------------------------------->

SlideShowButtonArea.prototype = new AreaBase();
function SlideShowButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function SlideShowButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "SlideShowButtonArea: " + msg);
	}
	
	function SlideShowButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		
		this.button.Initialize();
		
		this.AddEventHandlers();
		
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function SlideShowButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		
		this.RemoveEventHandlers();
	}
	
	function SlideShowButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.CommandEventHandler = new SfEventHandler("SlideShowButtonArea");
		this.CommandEventHandler.MethodName = "OnCommandEvent";
		this.CommandEventHandler.Container = this.Container;
		MainHelper.EventCommand.AddHandler(this.CommandEventHandler);
	}
	
	function SlideShowButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandlers");
		
		MainHelper.EventCommand.RemoveHandler(this.CommandEventHandler);
	}

	function SlideShowButtonArea.prototype.OnCommandEvent(args)
	{
		this.Debug("OnCommandEvent: " + args);
		switch(args.Command)
		{
			case SfCommandType.ShowSlideList:
				this.button.SetCheck(false);
				break;
		}
	}
	
	function SlideShowButtonArea.prototype.OnClick()
	{
		this.Debug("OnClick");
		
		if (this.button.IsChecked == true)
		{
			return;
		}
		
		this.button.SetCheck(true);
	
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.ShowSlideShow));
	
		var slide = SfDOM.FindElementFromID(document, "lblSlide");
		if (slide)
		{
			slide.style.visibility = 'visible';
		}
	}
	
}

// ENDFILE SlideShowButtonArea.js ---------------------------------------------------------------------->

// BEGINFILE StopButtonArea.js ------------------------------------------------------------------------->

StopButtonArea.prototype = new AreaBase();
function StopButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function StopButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "StopButtonArea: " + msg);
	}
	
	function StopButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.AddEventHandlers();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function StopButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.RemoveEventHandlers();
	}
	
	function StopButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.PlayerSetupCompleteEventHandler = new SfEventHandler("StopButtonArea");
		this.PlayerSetupCompleteEventHandler.MethodName = "OnPlayerSetupCompleteEvent";
		this.PlayerSetupCompleteEventHandler.Container = this.Container;
		MainHelper.EventPlayerSetupComplete.AddHandler(this.PlayerSetupCompleteEventHandler);
		
		this.PlayerStateChangedEventHandler = new SfEventHandler("StopButtonArea");
		this.PlayerStateChangedEventHandler.MethodName = "OnPlayerStateChangedEvent";
		this.PlayerStateChangedEventHandler.Container = this.Container;
		MainHelper.EventPlayerStateChanged.AddHandler(this.PlayerStateChangedEventHandler);
	}
	
	function StopButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventPlayerSetupComplete.RemoveHandler(this.PlayerSetupCompleteEventHandler);
		MainHelper.EventPlayerStateChanged.RemoveHandler(this.PlayerStateChangedEventHandler);
	}

	function StopButtonArea.prototype.OnPlayerSetupCompleteEvent(args)
	{
		this.Debug("OnPlayerSetupCompleteEvent called");
		this.button.Enable(true);
	}
	
	function StopButtonArea.prototype.OnPlayerStateChangedEvent(state)
	{
		this.Debug("OnPlayerStateChangedEvent: " + state);
		var stopIsEnabled = true;

		switch(state)
		{
			case PlayState.Paused:
			case PlayState.Stopped:
			case PlayState.Ready:
				stopIsEnabled = false;
				break;
			case PlayState.Playing:
				stopIsEnabled = true;
				break;
			default:
				return;
		}
	
		this.Debug("ButtonEnabledState: " + stopIsEnabled);
		if (stopIsEnabled)
		{
			if (this.button.IsEnabled == false)
			{
				this.button.Enable(true);
			}
		}
		else
		{
			if (this.button.IsEnabled == true)
			{
				this.button.Enable(false);
			}
		}
	}

	function StopButtonArea.prototype.OnClick()
	{
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.Stop));
	}
	
}

// ENDFILE StopButtonArea.js --------------------------------------------------------------------------->

// BEGINFILE TextSlideListButtonArea.js ---------------------------------------------------------------->

TextSlideListButtonArea.prototype = new AreaBase();
function TextSlideListButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function TextSlideListButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "TextSlideListButtonArea: " + msg);
	}
	
	function TextSlideListButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		
		this.button.Initialize();
		
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function TextSlideListButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
	}
	
	function TextSlideListButtonArea.prototype.OnClick()
	{
		this.Debug("OnClick");
		
		if (this.button.IsChecked == true)
		{
			return;
		}
		
		this.button.SetCheck(true);
	
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.ShowTextSlideList));
	}
	
}

// ENDFILE TextSlideListButtonArea.js ------------------------------------------------------------------>

// BEGINFILE VolumeDownButtonArea.js ------------------------------------------------------------------->

VolumeDownButtonArea.prototype = new AreaBase();
function VolumeDownButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function VolumeDownButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "VolumeDownButtonArea: " + msg);
	}
	
	function VolumeDownButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.AddEventHandlers();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function VolumeDownButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.RemoveEventHandlers();
	}
	
	function VolumeDownButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.PlayerSetupCompleteEventHandler = new SfEventHandler("VolumeDownButtonArea");
		this.PlayerSetupCompleteEventHandler.MethodName = "OnPlayerSetupCompleteEvent";
		this.PlayerSetupCompleteEventHandler.Container = this.Container;
		MainHelper.EventPlayerSetupComplete.AddHandler(this.PlayerSetupCompleteEventHandler);
	}
	
	function VolumeDownButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventPlayerSetupComplete.RemoveHandler(this.PlayerSetupCompleteEventHandler);
	}

	function VolumeDownButtonArea.prototype.OnPlayerSetupCompleteEvent(args)
	{
		this.Debug("OnPlayerSetupCompleteEvent called");
		this.button.Enable(true);
	}
	
	function VolumeDownButtonArea.prototype.OnClick()
	{
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.VolumeDown));
	}
	
}

// ENDFILE VolumeDownButtonArea.js --------------------------------------------------------------------->

// BEGINFILE VolumeUpButtonArea.js --------------------------------------------------------------------->

VolumeUpButtonArea.prototype = new AreaBase();
function VolumeUpButtonArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;
	
	this.InitializeArea(container, containingWindow, ID);
	
	function VolumeUpButtonArea.prototype.Debug(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "VolumeUpButtonArea: " + msg);
	}
	
	function VolumeUpButtonArea.prototype.OnLoad()
	{
		this.Debug("OnLoad");
		this.button.Initialize();
		this.AddEventHandlers();
		this.button.ClickHandler = new Function("", this.Container + ".OnClick();");
	}
	
	function VolumeUpButtonArea.prototype.OnUnLoad()
	{
		this.Debug("OnUnLoad");
		this.RemoveEventHandlers();
	}
	
	function VolumeUpButtonArea.prototype.AddEventHandlers()
	{
		this.Debug("AddEventHandlers");
		
		this.PlayerSetupCompleteEventHandler = new SfEventHandler("VolumeUpButtonArea");
		this.PlayerSetupCompleteEventHandler.MethodName = "OnPlayerSetupCompleteEvent";
		this.PlayerSetupCompleteEventHandler.Container = this.Container;
		MainHelper.EventPlayerSetupComplete.AddHandler(this.PlayerSetupCompleteEventHandler);
	}
	
	function VolumeUpButtonArea.prototype.RemoveEventHandlers()
	{
		this.Debug("RemoveEventHandler");
		
		MainHelper.EventPlayerSetupComplete.RemoveHandler(this.PlayerSetupCompleteEventHandler);
	}

	function VolumeUpButtonArea.prototype.OnPlayerSetupCompleteEvent(args)
	{
		this.Debug("OnPlayerSetupCompleteEvent called");
		this.button.Enable(true);
	}
	
	function VolumeUpButtonArea.prototype.OnClick()
	{
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.VolumeUp));
	}
	
}

// ENDFILE VolumeUpButtonArea.js ----------------------------------------------------------------------->
