
// Copyright (c) 2003 Sonic Foundry, Inc. and Sonic Foundry 
// Media Systems, Inc. Neither this code nor any portion 
// thereof maybe reproduced, altered,or otherwise changed, 
// distributed or copied,without the express written 
// permission of Sonic Foundry. 
// All rights reserved.

WM64LitePlayerArea.prototype = new PlayerArea();

function WM64LitePlayerArea(container, containingWindow, ID)
{
	this.m_debugLevel = SfDebug.Verbose;
//	this.m_debugLevel = SfDebug.Information;

	this.PlayerType = PlayerType.WM64Lite;
	this.IsSetupComplete = false;
	
	if (container && containingWindow && ID)
	{
		this.InitializeArea(container, containingWindow, ID);
		SfOnLoad.AddHandler(this.Container + ".DoOnLoad()", AreaNames.Global);
	}

	// can not call onload because of dependency between frames
	function WM64LitePlayerArea.prototype.OnLoad()
	{
		// do nothing
	}
	
	function WM64LitePlayerArea.prototype.SetupPlayer()
	{
		this.Debug("Setup Player called");

		this.evScriptHandler = new SfEventHandler("Player");
		this.evScriptHandler.MethodName = "LocalOnScriptEvent";
		this.evScriptHandler.Container = "PlayerAreaInstance";
		MainHelper.EventScript.AddHandler(this.evScriptHandler);

		this.evCommandHandler = new SfEventHandler("Player");
		this.evCommandHandler.MethodName = "LocalOnCommandEvent";
		this.evCommandHandler.Container = "PlayerAreaInstance";
		MainHelper.EventCommand.AddHandler(this.evCommandHandler);

		this.IsSetupComplete = true;
	}
	
	function WM64LitePlayerArea.prototype.OnUnLoad()
	{
		if (this.evScriptHandler)
		{
		    if (MainHelper && MainHelper.EventScript)
		    {
			    MainHelper.EventScript.RemoveHandler(this.evScriptHandler);
			}
		}
		this.evScriptHandler=null;
		if (this.evCommandHandler)
		{
		    if (MainHelper && MainHelper.EventCommand)
		    {
			    MainHelper.EventCommand.RemoveHandler(this.evCommandHandler);
			}
		}
		this.evCommandHandler=null;
    }

	function WM64LitePlayerArea.prototype.LoadVideo(slideNumber)
	{
		this.Debug("load video called, slideNumber: " + slideNumber);
		var macPlayerFrame = frames["FrameMacPlayer"];
		if (!macPlayerFrame)
		{
			SfDebug.DPF(SfDebug.ErrMsgCritical, "Could not find Mac frame");
			return;
		}
		var playerFrameSrc = Util.GetDocumentBase() + "Mac/FrameMacPlayer.aspx?" +
				SfRequestVariables.PresentationID + "=" + MainHelper.Presentation.PresentationID +
				"&" + SfRequestVariables.SlideNumber + "=" + slideNumber +
				"&" + SfRequestVariables.PresentationExperienceID + "=" + MainHelper.Presentation.PresentationExperienceID;

		this.Debug("Loading: " + playerFrameSrc);
		macPlayerFrame.location = playerFrameSrc;
	}

	function WM64LitePlayerArea.prototype.LocalOnScriptEvent(args)
	{
		switch(args.Command)
		{
			case SfScriptCommandType.EndPresentation:
				MainHelper.PresentationEnded = true;
				break;
		}
	}

	function WM64LitePlayerArea.prototype.LocalOnCommandEvent(args)
	{
		switch(args.Command)
		{
			case SfCommandType.NavigateToSlide:
				var slideNumber = args.SlideNumber;
				if (!slideNumber)
				{
					SfDebug.DPF(SfDebug.ErrMsgCritical, "Navigate to Slide no SlideNumber present");
					return;
				}
				this.NavigateToSlide(Number(slideNumber));
				break;
		}
	}
	
	function WM64LitePlayerArea.prototype.NavigateToSlide(slideNumber)
	{
		this.Debug("NavigateToSlide with slideNumber: " + slideNumber + " called");
		
		if (MainHelper.Presentation.Status != PresentationStatus.ReplayReady)
		{
			this.Debug("can not navigate when presentation is not on demand");
			return;
		}
		
		if (slideNumber < 1)
		{
			this.Debug("SlideNumber is less than 1");
			return;
		}
		if (MainHelper.MaxSlideTimings < slideNumber)
		{
			SfDebug.DPF(SfDebug.ErrMsgCritical, "slidetimings not known for slideNumber: " + slideNumber);
			return;
		}
		
		this.LoadVideo(slideNumber);
		
		// event is not automatically getting fired
		// so do it manually
		var args = MainHelper.CreateShowSlideEventArgs(slideNumber);
		this.ScriptParser.NotifyScriptEvent(args);
		
		MainHelper.EventCommand.Post(new CommandArgs(SfCommandType.ShowSlideShow));
	}
}
